@@ -98,7 +98,7 @@ exchAttachments.prototype = {
 
 		this.globalFunctions.LOG("exchWebService.attachments.addAttachment");
 		if (aAttachment.uri) {
-			let documentLink = this._document.getElementById("exchWebService-attachment-link");
+			let documentLink = this._document.getElementById("attachment-link");
 			let item = documentLink.appendChild(createXULElement("listitem"));
 			item.setAttribute("crop", "end");
 			item.setAttribute("class", "listitem-iconic");
@@ -187,7 +187,7 @@ exchAttachments.prototype = {
 
 	deleteAttachment: function deleteAttachment()
 	{
-		var documentLink = this._document.getElementById("exchWebService-attachment-link");
+		var documentLink = this._document.getElementById("attachment-link");
 		if ((documentLink.selectedItem) && (documentLink.selectedItem.attachment)) {
 			delete gAttachMap[documentLink.selectedItem.attachment.hashId];
 			documentLink.removeItemAt(documentLink.selectedIndex);
@@ -220,7 +220,7 @@ exchAttachments.prototype = {
 
 	removeItemsFromListbox: function _removeItemsFromListbox()
 	{
-		var documentLink = this._document.getElementById("exchWebService-attachment-link");
+		var documentLink = this._document.getElementById("attachment-link");
 		while (documentLink.itemCount > 0) {
 			this.globalFunctions.LOG(" == Removing item from listbox");
 			documentLink.removeItemAt(0);
@@ -332,7 +332,13 @@ exchAttachments.prototype = {
 
 		var taskTree = this._document.getElementById("calendar-task-tree");
 		var item = taskTree.currentTask;
-
+		var displayElement=function(id,flag) {
+            setBooleanAttribute(id, "hidden", !flag);
+            return flag;
+        }
+		if (displayElement("calendar-task-details-container", item != null) &&
+            displayElement("calendar-task-view-splitter", item != null)) { 
+			
 		if ((item.calendar) && (item.calendar.type == "exchangecalendar")) {
 			// calendar-task-view (hide existing attachment view)
 			//this.globalFunctions.LOG("exchWebService.attachments.onSelectTask: it is an Exchange task 1.");
@@ -370,13 +376,14 @@ exchAttachments.prototype = {
 			catch (ex) {this.globalFunctions.LOG("exchWebService.attachments.onSelectTask: Foutje Y:");}
 			this.attachmentListboxVisible = false;
 		}
+		}
 	},
 
 	onSelect: function _onSelect(aEvent)
 	{
 		this.globalFunctions.LOG("exchWebService.attachments.onSelect");
 
-		let documentLink = this._document.getElementById("exchWebService-attachment-link");
+		let documentLink = this._document.getElementById("attachment-link");
 
 		var isReadOnly = "true";
 		if ((this._document.getElementById("calendar-event-dialog")) || (this._document.getElementById("calendar-task-dialog"))) {
@@ -421,7 +428,7 @@ exchAttachments.prototype = {
 	openAttachment: function _openAttachment()
 	{
 		this.globalFunctions.LOG("exchWebService.attachments.openAttachment");
-		let documentLink = this._document.getElementById("exchWebService-attachment-link");
+		let documentLink = this._document.getElementById("attachment-link");
 
 		if (documentLink.selectedItem.attachment) {
 			var attURI = documentLink.selectedItem.attachment.uri;
@@ -442,7 +449,7 @@ exchAttachments.prototype = {
 	saveAttachment: function _saveAttachment()
 	{
 		this.globalFunctions.LOG("exchWebService.attachments.saveAttachment");
-		let documentLink = this._document.getElementById("exchWebService-attachment-link");
+		let documentLink = this._document.getElementById("attachment-link");
 		this.downloadAttachment(documentLink.selectedItem.attachment, true);
 	},
 
